==> haskell-coinbase-pro-0.9.3.2-159-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-AoNU7Pq6G7kFIZMSLUvxFv
key:                  coinbase-pro-0.9.3.2-AoNU7Pq6G7kFIZMSLUvxFv
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a54543990ced842c5bb7ab668232215e
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-AoNU7Pq6G7kFIZMSLUvxFv
depends:
    HsOpenSSL-0.11.7.6-2HSl0NfZkq9CNnRc3ihjq3
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    aeson-casing-0.2.0.0-AFiXjXUwpwBIniss331GSg
    async-2.2.5-b1lsUdcpsoF4yB7f3qI00 base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-2G7emN3aUjLCPswZX3R9DV exceptions-0.10.4
    http-api-data-0.5.1-U0fZvIQEYNFA9HYDriMAQ
    http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-client-tls-0.3.6.3-vm9lZXKKPQG6YiMQwXwb7
    http-streams-0.8.9.9-E3cmxBtnZQKFIygCWnD8h6
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    io-streams-1.5.2.2-Jbsyhau6FVRBBJb0nhRNA
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    servant-0.20.1-GLej8ldIOOu81Qu62QAP65
    servant-client-0.20-ANeZTzgUxwH9gRYRpGDNay
    servant-client-core-0.20-HaYOWP3vx4FCl7MBpWbcbp
    tasty-1.4.3-3WNUiw7s1TODR5TnJa9k2E
    tasty-hunit-0.10.1-LyJIg8bvf7G6jsUeDo4J9U text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unagi-streams-0.2.7-9OtPmb0TCmHcOA19jgvEz
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    uuid-1.3.15-5G75epcUDQqCLu4om96pvk
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq
    websockets-0.12.7.3-CsyYfP2OlfU5v7dCXjTAWE
    wuss-2.0.1.1-CF5G4aS6xl25bjByF1ba2c

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-189-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-4WQuBwvgkVK2KQ9Ca9v99l
key:                  coinbase-pro-0.9.3.2-4WQuBwvgkVK2KQ9Ca9v99l
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  cf944ae943aaec8842c3b58ed695403d
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-4WQuBwvgkVK2KQ9Ca9v99l
depends:
    HsOpenSSL-0.11.7.6-2EI6PO3Kfl51FoShESk8Fp
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-casing-0.2.0.0-23ym5VdXq4C4xoL0DnMx8y
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep exceptions-0.10.4
    http-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    http-streams-0.8.9.9-ClURJ32gbQ3ArIeRxTmOos
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    io-streams-1.5.2.2-6SGR25X7anB2y3sILEGjaX
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    servant-0.20.2-Ao9FJb1nrGg31HF8azeLuw
    servant-client-0.20-8D8xgQkcaQD1l8EGN94lYc
    servant-client-core-0.20.2-7zLiiUml5Y9KrgELjn5oYN
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7
    tasty-hunit-0.10.1-4ZYp83MGxX28IFU2SfTwqM text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unagi-streams-0.2.7-HXd4eDaeQ4TFZmxYis61VR
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    uuid-1.3.15-7dlZ5e7FtKwKVMt3dzHFPs
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    websockets-0.12.7.3-76PLcVimgTmIzbKQenv4SO
    wuss-2.0.1.1-dU6F5fu4Uy4esuuD25XRU

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
